@@ -10,11 +10,8 @@ import typing_extensions
 
 import aws_cdk.assets._jsii
 import aws_cdk.aws_athena._jsii
-import aws_cdk.aws_cloudformation._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_eks._jsii
-import aws_cdk.aws_emr._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_glue._jsii
@@ -32,24 +29,18 @@ import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.aws_s3_deployment._jsii
 import aws_cdk.aws_s3_notifications._jsii
-import aws_cdk.aws_sagemaker._jsii
-import aws_cdk.aws_sam._jsii
-import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.aws_sns._jsii
-import aws_cdk.aws_sns_subscriptions._jsii
-import aws_cdk.aws_sqs._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.aws_stepfunctions_tasks._jsii
 import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
-import aws_cdk.region_info._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@randyridgley/cdk-datalake-constructs",
-    "0.0.36",
+    "0.0.39",
     __name__[0:-6],
-    "cdk-datalake-constructs@0.0.36.jsii.tgz",
+    "cdk-datalake-constructs@0.0.39.jsii.tgz",
 )
 
 __all__ = [
